"""
.. module:: teamcontrol.control
   :platform: Unix, Windows
   :synopsis: Main application controller

.. moduleauthor:: Caio Romao <caioromao@gmail.com>

"""


class TeamController():
    def __init__(self, scm, config, team_name=None):
        self._team_name = team_name
        self._team_users_map = {}
        self._rule_team_relation = []
        self.__scm = scm

        # build internal data structures
        for name, users, rules in config.get_teams():
            self._team_users_map[name] = set(users)
            for rule in rules:
                self._rule_team_relation.append((rule, name))

    def get_interested_users(self, filename):
        users = set()
        for rule, team in self._rule_team_relation:
            if rule.match(filename):
                users |= self._team_users_map[team]
        return users

    def get_emails(self, input_data):
        emails = set()
        if self._team_name is not None:
            emails = self._team_users_map.get(self._team_name, set())

        changed_files = self.__scm.get_files(input_data)
        for filename in changed_files:
            emails |= self.get_interested_users(filename)

        return emails
